@@ -1,7 +1,8 @@
 """Top-level package for pyzerproc."""
-from .discovery import discover_devices  # noqa: F401
+from .discovery import discover  # noqa: F401
 from .light import Light, LightState  # noqa: F401
+from .exceptions import *  # noqa: F401, F403
 
 __author__ = """Emily Mills"""
 __email__ = 'emily@emlove.me'
-__version__ = '0.1.1'
+__version__ = '0.2.1'
